@@ -34,10 +34,9 @@
 #include <goffice/graph/gog-grid-line.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-error-bar.h>
-#include <goffice/graph/gog-reg-eqn.h>
 #include <goffice/graph/gog-series-lines.h>
 #include <goffice/data/go-data-simple.h>
-#include <goffice/utils/format.h>
+#include <goffice/utils/go-format.h>
 #include <goffice/utils/go-font.h>
 #include <goffice/utils/go-math.h>
 #include <goffice/app/go-plugin-service.h>
@@ -95,7 +94,7 @@ libgoffice_init (void)
 }
 #endif
 
-	bindtextdomain ("libgoffice", libgoffice_locale_dir);
+	bindtextdomain (GETTEXT_PACKAGE, libgoffice_locale_dir);
 	go_fonts_init ();
 	go_math_init ();
 	gsf_init ();
