@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -131,8 +131,10 @@ typedef enum {
 	GOG_MS_DIM_ERR_minus1,	/* we made it up */
 	GOG_MS_DIM_ERR_plus2,	/* we made it up */
 	GOG_MS_DIM_ERR_minus2,	/* we made it up */
-	GOG_MS_DIM_DROPBAR,	/* we made it up */
-	GOG_MS_DIM_MINMAX,	/* we made it up */
+	GOG_MS_DIM_START,	/* we made it up for dropbars*/
+	GOG_MS_DIM_END,	/* we made it up for dropbars */
+	GOG_MS_DIM_LOW,	/* we made it up for hi-lo*/
+	GOG_MS_DIM_HIGH,	/* we made it up for hi-lo */
 } GogMSDimType;
 
 typedef enum {
@@ -157,11 +159,27 @@ typedef enum {
 	GOG_POSITION_MANUAL_Y_ABS = 1 << 9,
 	GOG_POSITION_MANUAL_X_END = 1 << 10, /* pos relative to start or end */
 	GOG_POSITION_MANUAL_Y_END = 1 << 11,
-	GOG_POSITION_ANY_MANUAL   = 0xf80,
 
-	GOG_POSITION_PADDING	  = 1 << 12
+	/* modifiers for manual */
+	GOG_POSITION_ANCHOR_NW       = 0 << 12,
+	GOG_POSITION_ANCHOR_N	     = 1 << 12,
+	GOG_POSITION_ANCHOR_NE	     = 2 << 12,
+	GOG_POSITION_ANCHOR_E        = 3 << 12,
+	GOG_POSITION_ANCHOR_SE       = 4 << 12,
+	GOG_POSITION_ANCHOR_S        = 5 << 12,
+	GOG_POSITION_ANCHOR_SW       = 6 << 12,
+	GOG_POSITION_ANCHOR_W        = 7 << 12,
+	GOG_POSITION_ANCHOR_CENTER   = 8 << 12,
+	GOG_POSITION_ANCHOR          = 0xf000,
+	
+	GOG_POSITION_ANY_MANUAL      = 0xff80,
+       	
+	GOG_POSITION_PADDING	     = 1 << 16
 } GogObjectPosition;
 
+#define GOG_POSITION_IS_SPECIAL(pos) (((pos) & GOG_POSITION_SPECIAL)&&(!((pos) & GOG_POSITION_MANUAL)))
+#define GOG_POSITION_IS_PADDING(pos) (((pos) & GOG_POSITION_PADDING)&&(!((pos) & GOG_POSITION_MANUAL)))
+
 /* #define NO_DEBUG_CHARTS */
 #ifndef NO_DEBUG_CHARTS
 #define gog_debug(level, code)	do { if (goffice_graph_debug_level > level) { code } } while (0)
