@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -40,7 +40,7 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
 #include <glade/glade-xml.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <string.h>
 
@@ -62,6 +62,8 @@ typedef struct {
 static void
 cb_destroy (G_GNUC_UNUSED GtkWidget *w, GogErrorBarEditor *editor)
 {
+	if (editor->bar)
+		g_object_unref (editor->bar);
 	g_free (editor);
 }
 
@@ -122,6 +124,7 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 		gog_dataset_set_dim (set, editor->bar->error_i, NULL, NULL);
 		gog_dataset_set_dim (set, editor->bar->error_i + 1, NULL, NULL);
 		g_object_set (editor->series, editor->property, NULL, NULL);
+		g_object_unref (editor->bar);
 		editor->bar = NULL;
 		data = g_object_get_data (G_OBJECT (w), "plus");
 		if (GTK_IS_WIDGET (data))
@@ -200,7 +203,7 @@ gog_error_bar_prefs (GogSeries *series,
 	}
 	set = GOG_DATASET (series);
 
-	gui = go_libglade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", NULL, cc);
+	gui = go_libglade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", GETTEXT_PACKAGE, cc);
 
 	/* Style properties */
 
@@ -377,7 +380,7 @@ gog_error_bar_persist_dom_load (GogPersist *gp, xmlNode *node)
 	}
 	str = xmlGetProp (node, CC2XML ("color"));
 	if (str != NULL) {
-		bar->style->line.color = go_color_from_str (str);
+		go_color_from_str (str, &bar->style->line.color);
 		xmlFree (str);
 	}
 
@@ -470,7 +473,6 @@ gog_error_bar_persist_sax_save (GogPersist const *gp, GsfXMLOut *output)
 	}
 	if (str != NULL)
 		gsf_xml_out_add_cstr_unchecked (output, "display", str);
-#warning Why 5.0 and why 1.0 ?
 	if (bar->width != 5.)
 		gsf_xml_out_add_float (output, "width", bar->width, 2);
 	if (bar->style->line.width != 1.)
@@ -479,17 +481,50 @@ gog_error_bar_persist_sax_save (GogPersist const *gp, GsfXMLOut *output)
 		go_xml_out_add_color (output, "color", bar->style->line.color);
 }
 
+static void
+geb_start (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogErrorBar *bar = GOG_ERROR_BAR (xin->user_state);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "error_type")) {
+			if (!strcmp (attrs[1], "absolute"))
+				bar->type = GOG_ERROR_BAR_TYPE_ABSOLUTE;
+			else if (!strcmp (attrs[1], "relative"))
+				bar->type = GOG_ERROR_BAR_TYPE_RELATIVE;
+			else if (!strcmp (attrs[1], "percent"))
+				bar->type = GOG_ERROR_BAR_TYPE_PERCENT;
+		} else if (0 == strcmp (attrs[0], "display")) {
+			if (!strcmp (attrs[1], "none"))
+				bar->display = GOG_ERROR_BAR_DISPLAY_NONE;
+			else if (!strcmp (attrs[1], "positive"))
+				bar->display = GOG_ERROR_BAR_DISPLAY_POSITIVE;
+			else if (!strcmp (attrs[1], "negative"))
+				bar->display = GOG_ERROR_BAR_DISPLAY_NEGATIVE;
+		} else if (0 == strcmp (attrs[0], "width"))
+			bar->width = g_strtod (attrs[1], NULL);
+		else if (0 == strcmp (attrs[0], "line_width"))
+			bar->style->line.width = g_strtod (attrs[1], NULL);
+		else if (0 == strcmp (attrs[0], "color"))
+			go_color_from_str (attrs[1], &bar->style->line.color);
+}
+
 static void
 gog_error_bar_persist_init (GogPersistClass *iface)
 {
+	static GsfXMLInNode const gog_error_bar_dtd[] = {
+	  GSF_XML_IN_NODE (ERRORBAR, ERRORBAR, -1, "GogObject", FALSE, &geb_start, NULL),
+	  GSF_XML_IN_NODE_END
+	};
 	iface->dom_load = gog_error_bar_persist_dom_load;
 	iface->dom_save = gog_error_bar_persist_dom_save;
 	iface->sax_save = gog_error_bar_persist_sax_save;
+#warning PLUG LEAK
+	iface->sax_doc  = gsf_xml_in_doc_new (gog_error_bar_dtd, NULL);
 }
 
 GSF_CLASS_FULL (GogErrorBar, gog_error_bar,
-		gog_error_bar_class_init, gog_error_bar_init,
-		G_TYPE_OBJECT, 0,
+		NULL, NULL, gog_error_bar_class_init, NULL,
+		gog_error_bar_init, G_TYPE_OBJECT, 0,
 		GSF_INTERFACE (gog_error_bar_persist_init, GOG_PERSIST_TYPE))
 
 
@@ -735,7 +770,7 @@ void gog_error_bar_render (const GogErrorBar *bar,
 		path[2].code = ART_END;
 
 	gog_renderer_push_style (rend, bar->style);
-	gog_renderer_draw_sharp_path (rend, path, NULL);
+	gog_renderer_draw_sharp_path (rend, path);
 	gog_renderer_pop_style (rend);
 }
 
