@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <goffice/goffice-config.h>
@@ -36,7 +36,7 @@
 #include <goffice/graph/gog-control-foocanvas.h>
 #include <goffice/gtk/goffice-gtk.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libxml/parser.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
@@ -222,14 +222,17 @@ graph_typeselect_minor (GraphGuruTypeSelector *typesel, FooCanvasItem *item)
 
 	g_return_if_fail (plot != NULL);
 
-	if (s->plot != NULL) {
-		GogObject *obj = GOG_OBJECT (s->plot);
+	if (s->chart != NULL) {
+		GogObject *obj = GOG_OBJECT (s->chart);
 		gog_object_clear_parent (obj);
 		g_object_unref (obj);
+		s->chart = GOG_CHART (gog_object_add_by_name (
+				GOG_OBJECT (s->graph), "Chart", NULL));
 	}
 
 	gog_object_add_by_name (GOG_OBJECT (s->chart),
 		"Plot", GOG_OBJECT (s->plot = plot));
+	gog_plot_guru_helper (plot);
 #if 0
 	if (s->original_plot != NULL &&
 	    !gog_plot_make_similar (s->plot, s->original_plot))
@@ -357,10 +360,8 @@ cb_typesel_sample_plot_resize (FooCanvas *canvas,
 	 * active when sample button is not depressed */
 	if (typesel->sample_graph_item != NULL)
 		foo_canvas_item_set (typesel->sample_graph_item,
-			"w", (double)alloc->width * 2.,
-			"h", (double)alloc->height * 2.,
-			"logical_width_pts",  (2. * 72. * (double)alloc->width) / 96.,
-			"logical_height_pts", (2. * 72. * (double)alloc->height) / 96.,
+			"w", (double)alloc->width,
+			"h", (double)alloc->height,
 			NULL);
 }
 
@@ -370,7 +371,6 @@ cb_sample_pressed (GraphGuruTypeSelector *typesel)
 	if (typesel->current_family_item == NULL)
 		return;
 
-	foo_canvas_set_pixels_per_unit (FOO_CANVAS (typesel->canvas), .5); /* 50% zoom */
 	if (typesel->sample_graph_item == NULL) {
 		GtkAllocation *size = &GTK_WIDGET (typesel->canvas)->allocation;
 		typesel->sample_graph_item = foo_canvas_item_new (typesel->graph_group,
@@ -394,7 +394,6 @@ cb_sample_released (GraphGuruTypeSelector *typesel)
 	if (typesel->current_family_item == NULL)
 		return;
 
-	foo_canvas_set_pixels_per_unit (FOO_CANVAS (typesel->canvas), 1.);
 	foo_canvas_item_hide (FOO_CANVAS_ITEM (typesel->graph_group));
 	foo_canvas_item_show (FOO_CANVAS_ITEM (typesel->current_family_item));
 	foo_canvas_item_show (FOO_CANVAS_ITEM (typesel->selector));
@@ -541,12 +540,13 @@ cb_graph_guru_delete_item (GraphGuruState *s)
 		GtkTreeIter iter;
 		GogObject *obj = s->prop_object;
 
-		/* select the parent before we delete */
+		/* store parent iter */
 		gtk_tree_model_iter_parent (GTK_TREE_MODEL (s->prop_model),
 			&iter, &s->prop_iter);
-		gtk_tree_selection_select_iter (s->prop_selection, &iter);
 		gog_object_clear_parent (obj);
 		g_object_unref (obj);
+		/* then select the parent after we delete */
+		gtk_tree_selection_select_iter (s->prop_selection, &iter);
 	}
 }
 
@@ -627,6 +627,7 @@ cb_graph_guru_add_plot (GtkWidget *w, GraphGuruState *s)
 	GogPlot *plot = gog_plot_new_by_type (type);
 	gog_object_add_by_name (GOG_OBJECT (s->prop_object),
 		"Plot", GOG_OBJECT (plot));
+	gog_plot_guru_helper (plot);
 	/* as a convenience add a series to the newly created plot */
 	gog_object_add_by_name (GOG_OBJECT (plot), "Series", NULL);
 }
@@ -638,10 +639,17 @@ cb_plot_family_menu_create (char const *id, GogPlotFamily *family,
 	GtkWidget *w, *menu;
 	GSList *ptr, *types = NULL;
 	GogPlotType *type;
+	GogAxisSet axis_set;
 
 	if (g_hash_table_size (family->types) <= 0)
 		return;
 
+	axis_set = gog_chart_get_axis_set (GOG_CHART (closure->state->prop_object));
+
+	if (axis_set != GOG_AXIS_SET_UNKNOWN &&
+	    family->axis_set != axis_set)
+		return;
+
 	menu = gtk_image_menu_item_new_with_label (_(family->name));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu),
 		gtk_image_new_from_pixbuf (
@@ -1016,7 +1024,7 @@ cb_canvas_select_item (FooCanvas *canvas, GdkEventButton *event,
 {
 	GogView *view;
 	GogRenderer *rend;
-	double x, y;
+	double x, y, item_x, item_y;
 
 	g_return_val_if_fail (FOO_IS_CANVAS (canvas), FALSE);
 
@@ -1025,10 +1033,14 @@ cb_canvas_select_item (FooCanvas *canvas, GdkEventButton *event,
 
 	g_object_get (G_OBJECT (s->sample_graph_item), "renderer", &rend, NULL);
 	g_object_get (G_OBJECT (rend), "view", &view, NULL);
+	g_object_unref (G_OBJECT (rend));
 	foo_canvas_window_to_world (canvas, event->x, event->y, &x, &y);
+	g_object_get (G_OBJECT(s->sample_graph_item), "x", &item_x, "y", &item_y, NULL);
 	gog_view_info_at_point (view,
-		x * canvas->pixels_per_unit,	y * canvas->pixels_per_unit,
+		(x - item_x) * canvas->pixels_per_unit,	
+		(y - item_y) * canvas->pixels_per_unit,
 		s->prop_object, &s->search_target, NULL);
+	g_object_unref (G_OBJECT (view));
 	if (s->search_target == NULL)
 		return FALSE;
 
@@ -1040,15 +1052,31 @@ cb_canvas_select_item (FooCanvas *canvas, GdkEventButton *event,
 
 static void
 cb_sample_plot_resize (FooCanvas *canvas,
-		       GtkAllocation *alloc, GraphGuruState *s)
+		       GtkAllocation *alloc, GraphGuruState *state)
 {
-	/* Use 96dpi and zoom */
-	double zoom = 1. / canvas->pixels_per_unit;
-	foo_canvas_item_set (s->sample_graph_item,
-		"w", (double)alloc->width * zoom,
-		"h", (double)alloc->height * zoom,
-		"logical_width_pts",  (72. * zoom * (double)alloc->width) / 96.,
-		"logical_height_pts", (72. * zoom * (double)alloc->height) / 96.,
+	double aspect_ratio;
+	double width, height, x, y;
+
+	gog_graph_get_size (state->graph, &width, &height);
+       	aspect_ratio = width / height;
+
+	if (alloc->width > alloc->height * aspect_ratio) {
+		height = alloc->height;
+		width = height * aspect_ratio;
+		x = (alloc->width - width) / 2.0;
+		y = 0.0;
+	} else {
+		width = alloc->width;
+		height = width / aspect_ratio;
+		x = 0.0;
+		y = (alloc->height - height) / 2.0;
+	}
+	
+	foo_canvas_item_set (state->sample_graph_item,
+		"w", width,
+		"h", height,
+		"x", x,
+		"y", y,
 		NULL);
 }
 
@@ -1087,7 +1115,6 @@ graph_guru_init_format_page (GraphGuruState *s)
 
 	/* Load up the sample view and make it fill the entire canvas */
 	w = glade_xml_get_widget (s->gui, "sample_canvas");
-	foo_canvas_set_pixels_per_unit (FOO_CANVAS (w), .5); /* 50% zoom */
 	s->sample_graph_item = foo_canvas_item_new (
 		foo_canvas_root (FOO_CANVAS (w)), GOG_CONTROL_FOOCANVAS_TYPE,
 		"model", s->graph,
@@ -1262,7 +1289,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	GtkWidget *selector;
 	GladeXML *gui;
 
-	gui = go_libglade_new ("gog-guru-type-selector.glade", "type_selector", NULL, s->cc);
+	gui = go_libglade_new ("gog-guru-type-selector.glade", "type_selector", GETTEXT_PACKAGE, s->cc);
 
 	typesel = g_new0 (GraphGuruTypeSelector, 1);
 	typesel->state = s;
@@ -1361,7 +1388,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 static gboolean
 graph_guru_init (GraphGuruState *s)
 {
-	s->gui = go_libglade_new ("gog-guru.glade", NULL, NULL, s->cc);
+	s->gui = go_libglade_new ("gog-guru.glade", NULL, GETTEXT_PACKAGE, s->cc);
         if (s->gui == NULL)
                 return TRUE;
 
