@@ -21,7 +21,6 @@
 
 #include <goffice/goffice-config.h>
 #include <goffice/graph/gog-reg-curve.h>
-#include <goffice/graph/gog-reg-eqn.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-plot-engine.h>
 #include <goffice/graph/gog-style.h>
@@ -36,8 +35,8 @@
 #include <goffice/utils/go-math.h>
 #include <goffice/gtk/goffice-gtk.h>
 #include <gsf/gsf-impl-utils.h>
-#include <glib/gi18n.h>
-#include <gtk/gtktable.h>
+#include <glib/gi18n-lib.h>
+#include <gtk/gtktogglebutton.h>
 
 #define GOG_REG_CURVE_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_REG_CURVE_TYPE, GogRegCurveClass))
 
@@ -45,6 +44,11 @@ static GObjectClass *reg_curve_parent_klass;
 
 static GType gog_reg_curve_view_get_type (void);
 
+enum {
+	REG_CURVE_PROP_0,
+	REG_CURVE_PROP_SKIP_INVALID,
+};
+
 static void
 gog_reg_curve_init_style (GogStyledObject *gso, GogStyle *style)
 {
@@ -53,6 +57,12 @@ gog_reg_curve_init_style (GogStyledObject *gso, GogStyle *style)
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
 
+static void
+skip_invalid_toggled_cb (GtkToggleButton* btn, GObject *obj)
+{
+	g_object_set (obj, "skip-invalid", gtk_toggle_button_get_active (btn), NULL);
+}
+
 static void
 gog_reg_curve_populate_editor (GogObject *gobj, 
 			  GogEditor *editor, 
@@ -64,7 +74,7 @@ gog_reg_curve_populate_editor (GogObject *gobj,
 	GladeXML *gui;
 	GogDataset *set = GOG_DATASET (gobj);
 
-	gui = go_libglade_new ("gog-reg-curve-prefs.glade", "reg-curve-prefs", NULL, cc);
+	gui = go_libglade_new ("gog-reg-curve-prefs.glade", "reg-curve-prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -79,9 +89,47 @@ gog_reg_curve_populate_editor (GogObject *gobj,
 	w = GTK_WIDGET (gog_data_allocator_editor (dalloc, set, 1, GOG_DATA_SCALAR));
 	gtk_widget_show (w);
 	gtk_table_attach (table, w, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+	w = glade_xml_get_widget (gui, "skip-invalid");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+					(GOG_REG_CURVE (gobj))->skip_invalid);
+	g_signal_connect (G_OBJECT (w), "toggled",
+		G_CALLBACK (skip_invalid_toggled_cb), gobj);
+	if ((GOG_REG_CURVE_GET_CLASS (gobj))->populate_editor != NULL)
+		(GOG_REG_CURVE_GET_CLASS (gobj))->populate_editor (GOG_REG_CURVE (gobj), table);
 
 
-	(GOG_OBJECT_CLASS(reg_curve_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
+	(GOG_OBJECT_CLASS (reg_curve_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
+}
+
+static void
+gog_reg_curve_get_property (GObject *obj, guint param_id,
+		       GValue *value, GParamSpec *pspec)
+{
+	GogRegCurve *rc = GOG_REG_CURVE (obj);
+	switch (param_id) {
+	case REG_CURVE_PROP_SKIP_INVALID:
+		g_value_set_boolean (value, rc->skip_invalid);
+		break;
+
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+}
+
+static void
+gog_reg_curve_set_property (GObject *obj, guint param_id,
+		       GValue const *value, GParamSpec *pspec)
+{
+	GogRegCurve *rc = GOG_REG_CURVE (obj);
+	switch (param_id) {
+	case REG_CURVE_PROP_SKIP_INVALID:
+		rc->skip_invalid = g_value_get_boolean (value);
+		gog_object_request_update (GOG_OBJECT (obj));
+		break;
+
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 return; /* NOTE : RETURN */
+	}
 }
 
 static void
@@ -93,6 +141,14 @@ gog_reg_curve_finalize (GObject *obj)
 		g_free (rc->bounds);
 		rc->bounds = NULL;
 	}
+	if (rc->a != NULL) {
+		g_free (rc->a);
+		rc->a = NULL;
+	}
+	if (rc->equation != NULL) {
+		g_free (rc->equation);
+		rc->equation = NULL;
+	}
 	(*reg_curve_parent_klass->finalize) (obj);
 }
 
@@ -107,7 +163,7 @@ gog_reg_curve_class_init (GogObjectClass *gog_klass)
 {
 	static GogObjectRole const roles[] = {
 		{ N_("Equation"), "GogRegEqn",	0,
-		  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
+		  GOG_POSITION_ANY_MANUAL, GOG_POSITION_MANUAL, GOG_OBJECT_NAME_BY_ROLE,
 		  NULL, NULL, NULL, NULL, NULL, NULL },
 	};
 	GObjectClass *gobject_klass = (GObjectClass *) gog_klass;
@@ -115,6 +171,8 @@ gog_reg_curve_class_init (GogObjectClass *gog_klass)
 	GogRegCurveClass *reg_curve_klass = (GogRegCurveClass *) gog_klass;
 	reg_curve_parent_klass = g_type_class_peek_parent (gog_klass);
 
+	gobject_klass->get_property = gog_reg_curve_get_property;
+	gobject_klass->set_property = gog_reg_curve_set_property;
 	gobject_klass->finalize = gog_reg_curve_finalize;
 	gog_klass->populate_editor	= gog_reg_curve_populate_editor;
 	style_klass->init_style = gog_reg_curve_init_style;
@@ -124,7 +182,11 @@ gog_reg_curve_class_init (GogObjectClass *gog_klass)
 
 	reg_curve_klass->get_value_at = NULL;
 	reg_curve_klass->get_equation = NULL;
-	reg_curve_klass->get_R2 = NULL;
+	reg_curve_klass->populate_editor = NULL;
+
+	g_object_class_install_property (gobject_klass, REG_CURVE_PROP_SKIP_INVALID,
+		g_param_spec_boolean ("skip-invalid", "skip-invalid",
+			"Skip invalid data", FALSE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 }
 
 static void
@@ -198,7 +260,7 @@ gog_reg_curve_get_equation (GogRegCurve *reg_curve)
 double
 gog_reg_curve_get_R2 (GogRegCurve *reg_curve)
 {
-	return (GOG_REG_CURVE_GET_CLASS (reg_curve))->get_R2 (reg_curve);
+	return reg_curve->R2;
 }
 
 void
@@ -256,6 +318,10 @@ gog_reg_curve_view_render (GogView *view, GogViewAllocation const *bbox)
 		gog_axis_map_free (y_map);
 		return;
 	}
+	
+	gog_renderer_push_clip (view->renderer, 
+		gog_renderer_get_rectangle_vpath (&view->residual)); 
+	
 	x = g_new (double, rc->ninterp + 3);
 	y = g_new (double, rc->ninterp + 3);
 	gog_axis_get_bounds (plot->axis[0], x, x + rc->ninterp + 1);
@@ -280,6 +346,9 @@ gog_reg_curve_view_render (GogView *view, GogViewAllocation const *bbox)
 	art_free (path);
 	gog_axis_map_free (x_map);
 	gog_axis_map_free (y_map);
+
+	gog_renderer_pop_clip (view->renderer);
+	
 	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next)
 		gog_view_render	(ptr->data, bbox);
 }
