@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -33,6 +33,7 @@
 #include <goffice/gtk/go-combo-pixmaps.h>
 #include <goffice/gtk/goffice-gtk.h>
 #include <goffice/gtk/go-font-sel.h>
+#include <goffice/gtk/go-rotation-sel.h>
 
 #include <glade/glade-xml.h>
 #include <gtk/gtkcheckbutton.h>
@@ -47,7 +48,7 @@
 #include <gdk-pixbuf/gdk-pixdata.h>
 
 #include <gsf/gsf-impl-utils.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <string.h>
 #include <math.h>
 
@@ -69,6 +70,7 @@ static GObjectClass *parent_klass;
 
 typedef struct {
 	GladeXML  	*gui;
+	GladeXML  	*font_gui;
 	GogStyle  	*style;
 	GogStyle  	*default_style;
 	GObject		*object_with_style;
@@ -112,6 +114,7 @@ set_style (StylePrefState const *state)
 static GtkWidget *
 create_go_combo_color (StylePrefState *state,
 		       GOColor initial_val, GOColor default_val,
+		       GladeXML *gui,
 		       char const *group, char const *label_name,
 		       GCallback func)
 {
@@ -122,7 +125,7 @@ create_go_combo_color (StylePrefState *state,
 	go_combo_color_set_instant_apply (GO_COMBO_COLOR (w), FALSE);
 	go_combo_color_set_allow_alpha (GO_COMBO_COLOR (w), TRUE);
 	gtk_label_set_mnemonic_widget (
-		GTK_LABEL (glade_xml_get_widget (state->gui, label_name)), w);
+		GTK_LABEL (glade_xml_get_widget (gui, label_name)), w);
 	go_combo_color_set_color (GO_COMBO_COLOR (w), initial_val);
 	g_signal_connect (G_OBJECT (w),
 		"color_changed",
@@ -146,6 +149,9 @@ gog_style_set_image_preview (GdkPixbuf *pix, StylePrefState *state)
 			g_object_ref (state->fill.image.image);
 	}
 
+	if (pix == NULL)
+		return;
+
 	w = glade_xml_get_widget (state->gui, "fill_image_sample");
 
 	scaled = go_pixbuf_intelligent_scale (pix, HSCALE, VSCALE);
@@ -231,6 +237,7 @@ outline_init (StylePrefState *state, gboolean enable)
 	/* Color */
 	w = create_go_combo_color (state,
 		style->outline.color, default_style->outline.color,
+		state->gui,
 		"outline_color", "outline_color_label",
 		G_CALLBACK (cb_outline_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 1, 2, 0, 0, 0, 0);
@@ -311,6 +318,7 @@ line_init (StylePrefState *state, gboolean enable)
 	/* Colour */
 	w = create_go_combo_color (state,
 		style->line.color, default_style->line.color,
+		state->gui,
 		"line_color", "line_color_label",
 		G_CALLBACK (cb_line_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 1, 2, 0, 0, 0, 0);
@@ -407,6 +415,7 @@ fill_pattern_init (StylePrefState *state)
 	state->fill.pattern.fore = w = create_go_combo_color (state,
 		style->fill.pattern.fore,
 		default_style->fill.pattern.fore,
+		state->gui,
 		"pattern_foreground", "fill_pattern_foreground_label",
 		G_CALLBACK (cb_fg_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 1, 2, 0, 0, 0, 0);
@@ -414,6 +423,7 @@ fill_pattern_init (StylePrefState *state)
 	state->fill.pattern.back = w = create_go_combo_color (state,
 		style->fill.pattern.back,
 		default_style->fill.pattern.back,
+		state->gui,
 		"pattern_background", "fill_pattern_background_label",
 		G_CALLBACK (cb_bg_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 2, 3, 0, 0, 0, 0);
@@ -553,6 +563,7 @@ fill_gradient_init (StylePrefState *state)
 	state->fill.gradient.start = w = create_go_combo_color (state,
 		style->fill.pattern.back,
 		default_style->fill.pattern.back,
+		state->gui,
 		"gradient_start", "fill_gradient_start_label",
 		G_CALLBACK (cb_fill_gradient_start_color));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 2, 3, 0, 0, 0, 0);
@@ -561,6 +572,7 @@ fill_gradient_init (StylePrefState *state)
 	state->fill.gradient.end = w = create_go_combo_color (state,
 		style->fill.pattern.fore,
 		default_style->fill.pattern.fore,
+		state->gui,
 		"gradient_end", "fill_gradient_end_label",
 		G_CALLBACK (cb_fill_gradient_end_color));
 	gtk_table_attach (GTK_TABLE (table), w, 3, 4, 2, 3, 0, 0, 0, 0);
@@ -814,6 +826,7 @@ marker_init (StylePrefState *state, gboolean enable)
 	w = create_go_combo_color (state,
 		go_marker_get_fill_color (style->marker.mark),
 		go_marker_get_fill_color (default_style->marker.mark),
+		state->gui,
 		"pattern_foreground", "marker_fill_label",
 		G_CALLBACK (cb_marker_fill_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 1, 2, 0, 0, 0, 0);
@@ -821,6 +834,7 @@ marker_init (StylePrefState *state, gboolean enable)
 	w = create_go_combo_color (state,
 		go_marker_get_outline_color (style->marker.mark),
 		go_marker_get_outline_color (default_style->marker.mark),
+		state->gui,
 		"pattern_foreground", "marker_outline_label",
 		G_CALLBACK (cb_marker_outline_color_changed));
 	gtk_table_attach (GTK_TABLE (table), w, 1, 2, 2, 3, 0, 0, 0, 0);
@@ -855,38 +869,86 @@ cb_font_changed (GOFontSel *fs, PangoAttrList *list,
 }
 
 static void
-font_init (StylePrefState *state, guint32 enable, GogEditor *editor)
+cb_font_color_changed (G_GNUC_UNUSED GOComboColor *cc, GOColor color,
+		       G_GNUC_UNUSED gboolean is_custom,
+		       G_GNUC_UNUSED gboolean by_user,
+		       gboolean is_auto, StylePrefState *state)
+{
+	GogStyle *style = state->style;
+
+	style->font.color = color;
+	set_style (state);
+}
+
+static void
+font_init (StylePrefState *state, guint32 enable, GogEditor *editor, GOCmdContext *cc)
 {
 	GogStyle *style = state->style;
 	GtkWidget *w, *box;
+	GladeXML *gui;
 
 	if (!enable)
 		return;
 
 	g_return_if_fail (style->font.font != NULL);
 
-	box = gtk_vbox_new (FALSE, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (box), 12);
+	gui = go_libglade_new ("gog-style-prefs.glade", "gog_style_font_prefs", GETTEXT_PACKAGE, cc);
+	if (gui == NULL)
+		return;
 
-#if 0
-	w = gtk_check_button_new_with_label (_("Automatic"));
-	gtk_box_pack_start (GTK_BOX (box), w, FALSE, TRUE, 0);
-#endif
-	gtk_widget_show_all (box);
+	state->font_gui = gui;
 
+	w = create_go_combo_color (state,
+		style->font.color,
+		style->font.color,
+		gui,
+		"pattern_foreground", "font_color_label",
+		G_CALLBACK (cb_font_color_changed));
+	box = glade_xml_get_widget (gui, "color_box");
+	gtk_box_pack_start (GTK_BOX (box), w, TRUE, TRUE, 0);
+	gtk_widget_show (w);
+				    
 	w = go_font_sel_new ();
 	go_font_sel_set_font (GO_FONT_SEL (w), style->font.font);
 	g_signal_connect (G_OBJECT (w),
 		"font_changed",
 		G_CALLBACK (cb_font_changed), state);
-	gtk_box_pack_end (GTK_BOX (box), w, TRUE, TRUE, 0);
 	gtk_widget_show (w);
 
+ 	box = glade_xml_get_widget (gui, "gog_style_font_prefs");
+	gtk_box_pack_end (GTK_BOX (box), w, TRUE, TRUE, 0);
+	
 	gog_editor_add_page (editor, box, _("Font"));
 }
 
 /************************************************************************/
 
+static void
+cb_angle_changed (GORotationSel *grs, int angle, StylePrefState *state)
+{
+	gog_style_set_text_angle (state->style, angle);
+	set_style (state);
+}
+
+static void
+text_layout_init (StylePrefState *state, guint32 enable, GogEditor *editor, GOCmdContext *cc)
+{
+	GogStyle *style = state->style;
+	GtkWidget *w;
+
+	if (!enable)
+		return;
+
+	w = go_rotation_sel_new ();
+	go_rotation_sel_set_rotation (GO_ROTATION_SEL (w),
+		style->text_layout.angle);
+	g_signal_connect (G_OBJECT (w), "rotation-changed",
+		G_CALLBACK (cb_angle_changed), state);
+	gog_editor_add_page (editor, w, _("Text"));
+}
+
+/************************************************************************/
+
 static void
 cb_parent_is_gone (StylePrefState *state, GObject *where_the_object_was)
 {
@@ -906,6 +968,8 @@ gog_style_pref_state_free (StylePrefState *state)
 	g_object_unref (state->style);
 	g_object_unref (state->default_style);
 	g_object_unref (state->gui);
+	if (state->font_gui != NULL)
+		g_object_unref (state->font_gui);
 	if (state->fill.gradient.timer != 0) {
 		g_source_remove (state->fill.gradient.timer);
 		state->fill.gradient.timer = 0;
@@ -918,10 +982,10 @@ gog_style_pref_state_free (StylePrefState *state)
 void
 gog_style_populate_editor (GogStyle *style,
 			   GogEditor *editor,
-	      GogStyle *default_style,
-	      GOCmdContext *cc,
-	      GObject	*object_with_style,
-	      gboolean   watch_for_external_change)
+			   GogStyle *default_style,
+			   GOCmdContext *cc,
+			   GObject	*object_with_style,
+			   gboolean   watch_for_external_change)
 {
 	GogStyleFlag enable;
 	GtkWidget *w;
@@ -933,7 +997,7 @@ gog_style_populate_editor (GogStyle *style,
 
 	enable = style->interesting_fields;
 
-	gui = go_libglade_new ("gog-style-prefs.glade", "gog_style_prefs", NULL, cc);
+	gui = go_libglade_new ("gog-style-prefs.glade", "gog_style_prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -942,6 +1006,7 @@ gog_style_populate_editor (GogStyle *style,
 
 	state = g_new0 (StylePrefState, 1);
 	state->gui = gui;
+	state->font_gui = NULL;
 	state->style = style;
 	state->default_style = default_style;
 	state->object_with_style = object_with_style;
@@ -952,11 +1017,12 @@ gog_style_populate_editor (GogStyle *style,
 		"state", state, (GDestroyNotify) gog_style_pref_state_free);
 	gog_editor_add_page (editor, w, _("Style"));
 	
-	outline_init (state, enable & GOG_STYLE_OUTLINE);
-	line_init    (state, enable & GOG_STYLE_LINE);
-	fill_init    (state, enable & GOG_STYLE_FILL);
-	marker_init  (state, enable & GOG_STYLE_MARKER);
-	font_init    (state, enable & GOG_STYLE_FONT, editor);
+	outline_init 	 (state, enable & GOG_STYLE_OUTLINE);
+	line_init    	 (state, enable & GOG_STYLE_LINE);
+	fill_init    	 (state, enable & GOG_STYLE_FILL);
+	marker_init  	 (state, enable & GOG_STYLE_MARKER);
+	font_init    	 (state, enable & GOG_STYLE_FONT, editor, cc);
+	text_layout_init (state, enable & GOG_STYLE_TEXT_LAYOUT, editor, cc);
 
 	state->enable_edit = TRUE;
 
@@ -1048,6 +1114,8 @@ gog_style_assign (GogStyle *dst, GogStyle const *src)
 	if (GOG_FILL_STYLE_IMAGE == dst->fill.type)
 		dst->fill.image.filename = g_strdup (dst->fill.image.filename);
 
+	dst->text_layout = src->text_layout;
+
 	dst->interesting_fields = src->interesting_fields;
 	dst->disable_theming = src->disable_theming;
 }
@@ -1090,6 +1158,8 @@ gog_style_apply_theme (GogStyle *dst, GogStyle const *src)
 	if (dst->marker.auto_fill_color)
 		go_marker_set_fill_color (dst->marker.mark,
 			go_marker_get_fill_color (src->marker.mark));
+	if (dst->text_layout.auto_angle)
+		dst->text_layout.angle = src->text_layout.angle;
 
 #if 0
 	/* Fonts are not themed until we have some sort of auto mechanism
@@ -1146,6 +1216,7 @@ gog_style_init (GogStyle *style)
 	go_pattern_set_solid (&style->fill.pattern, RGBA_BLACK);
 	style->font.font = go_font_new_by_index (0);
 	style->font.color = RGBA_BLACK;
+	style->text_layout.angle = 0.0;
 }
 
 static struct {
@@ -1172,6 +1243,19 @@ bool_prop (xmlNode *node, char const *name, gboolean *res)
 	return FALSE;
 }
 
+static gboolean
+bool_sax_prop (char const *name, char const *id, char const *val, gboolean *res)
+{
+	if (0 == strcmp (name, id)) {
+		*res = g_ascii_tolower (*val) == 't' ||
+			g_ascii_tolower (*val) == 'y' ||
+			strtol (val, NULL, 0);
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 static GogFillStyle
 str_as_fill_style (char const *name)
 {
@@ -1218,7 +1302,7 @@ gog_style_line_load (xmlNode *node, GogStyleLine *line)
 	}
 	str = xmlGetProp (node, "color");
 	if (str != NULL) {
-		line->color = go_color_from_str (str);
+		go_color_from_str (str, &line->color);
 		xmlFree (str);
 	}
 	if (bool_prop (node, "auto-color", &tmp))
@@ -1324,8 +1408,7 @@ gog_style_gradient_load (xmlNode *node, GogStyle *style)
 	}
 	str = xmlGetProp (node, "start-color");
 	if (str != NULL) {
-		style->fill.pattern.back
-			= go_color_from_str (str);
+		go_color_from_str (str, &style->fill.pattern.back);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, "brightness");
@@ -1335,8 +1418,7 @@ gog_style_gradient_load (xmlNode *node, GogStyle *style)
 	} else {
 		str = xmlGetProp (node, "end-color");
 		if (str != NULL) {
-			style->fill.pattern.fore
-				= go_color_from_str (str);
+			go_color_from_str (str, &style->fill.pattern.fore);
 			xmlFree (str);
 		}
 	}
@@ -1398,14 +1480,12 @@ gog_style_fill_load (xmlNode *node, GogStyle *style)
 				}
 				str = xmlGetProp (ptr, "fore");
 				if (str != NULL) {
-					style->fill.pattern.fore
-						 = go_color_from_str (str);
+					go_color_from_str (str, &style->fill.pattern.fore);
 					xmlFree (str);
 				}
 				str = xmlGetProp (ptr, "back");
 				if (str != NULL) {
-					style->fill.pattern.back
-						 = go_color_from_str (str);
+					go_color_from_str (str, &style->fill.pattern.back);
 					xmlFree (str);
 				}
 			}
@@ -1471,6 +1551,7 @@ static void
 gog_style_marker_load (xmlNode *node, GogStyle *style)
 {
 	char *str;
+	GOColor c;
 	GOMarker *marker = go_marker_dup (style->marker.mark);
 
 	str = xmlGetProp (node, "shape");
@@ -1484,14 +1565,16 @@ gog_style_marker_load (xmlNode *node, GogStyle *style)
 	if (str != NULL) {
 		style->marker.auto_outline_color = TRUE;
 		bool_prop (node, "auto-outline", &style->marker.auto_outline_color);
-		go_marker_set_outline_color (marker, go_color_from_str (str));
+		if (go_color_from_str (str, &c))
+			go_marker_set_outline_color (marker, c);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, "fill-color");
 	if (str != NULL) {
 		style->marker.auto_fill_color = TRUE;
 		bool_prop (node, "auto-fill", &style->marker.auto_fill_color);
-		go_marker_set_fill_color (marker, go_color_from_str (str));
+		if (go_color_from_str (str, &c))
+			go_marker_set_fill_color (marker, c);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, "size");
@@ -1559,7 +1642,7 @@ gog_style_font_load (xmlNode *node, GogStyle *style)
 
 	str = xmlGetProp (node, "color");
 	if (str != NULL) {
-		style->font.color = go_color_from_str (str);
+		go_color_from_str (str, &style->font.color);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, "font");
@@ -1605,6 +1688,39 @@ gog_style_font_sax_save (GsfXMLOut *output, GogStyle const *style)
 	gsf_xml_out_end_element (output);
 }
 
+static void
+gog_style_text_layout_load (xmlNode *node, GogStyle *style)
+{
+	char *str;
+
+	str = xmlGetProp (node, "angle");
+	if (str != NULL) {
+		gog_style_set_text_angle (style, g_strtod (str, NULL));
+		xmlFree (str);
+	}
+}
+
+static void
+gog_style_text_layout_dom_save (xmlNode *parent, GogStyle const *style)
+{
+	gchar *str;
+	xmlNode *node = xmlNewDocNode (parent->doc, NULL, "text_layout", NULL);
+
+	str = g_strdup_printf ("%g", style->text_layout.angle);
+	xmlSetProp (node, (xmlChar const *) "angle", str);
+	g_free (str);
+
+	xmlAddChild (parent, node);
+}
+
+static void
+gog_style_text_layout_sax_save (GsfXMLOut *output, GogStyle const *style)
+{
+	gsf_xml_out_start_element (output, "text_layout");
+	gsf_xml_out_add_float (output, "angle", style->text_layout.angle, 1);
+	gsf_xml_out_end_element (output);
+}
+
 static gboolean
 gog_style_persist_dom_load (GogPersist *gp, xmlNode *node)
 {
@@ -1625,6 +1741,8 @@ gog_style_persist_dom_load (GogPersist *gp, xmlNode *node)
 			gog_style_marker_load (ptr, style);
 		else if (strcmp (ptr->name, "font") == 0)
 			gog_style_font_load (ptr, style);
+		else if (strcmp (ptr->name, "text_layout") == 0)
+			gog_style_text_layout_load (ptr, style);
 	}
 	return TRUE;
 }
@@ -1647,6 +1765,126 @@ gog_style_persist_dom_save (GogPersist const *gp, xmlNode *parent)
 		gog_style_marker_dom_save (parent, style);
 	if (style->interesting_fields & GOG_STYLE_FONT)
 		gog_style_font_dom_save (parent, style);
+	if (style->interesting_fields & GOG_STYLE_TEXT_LAYOUT)
+		gog_style_text_layout_dom_save (parent, style);
+}
+
+static void
+gog_style_sax_load_line (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+#warning TODO TODO
+	GogStyleLine *line = 0 ? &style->outline : &style->line;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "dash"))
+			line->dash_type = go_line_dash_from_str (attrs[1]);
+		else if (bool_sax_prop ("auto-dash", attrs[0], attrs[1], &line->auto_dash))
+			;
+		else if (0 == strcmp (attrs[0], "width")) {
+			line->width = g_strtod (attrs[1], NULL);
+			/* For compatibility with older graphs, when dash_type
+			 * didn't exist */
+			if (line->width < 0.) {
+				line->width = 0.;
+				line->dash_type = GO_LINE_NONE;
+			}
+		} else if (0 == strcmp (attrs[0], "color"))
+			go_color_from_str (attrs[1], &line->color);
+		else if (bool_sax_prop ("auto-dash", attrs[0], attrs[1], &line->auto_color))
+			;
+}
+static void
+gog_style_sax_load_fill_pattern (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	g_return_if_fail (style->fill.type == GOG_FILL_STYLE_PATTERN);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "type"))
+			style->fill.pattern.pattern = go_pattern_from_str (attrs[1]);
+		else if (0 == strcmp (attrs[0], "fore"))
+			go_color_from_str (attrs[1], &style->fill.pattern.fore);
+		else if (0 == strcmp (attrs[0], "back"))
+			go_color_from_str (attrs[1], &style->fill.pattern.back);
+}
+
+static void
+gog_style_sax_load_fill_gradient (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	g_return_if_fail (style->fill.type == GOG_FILL_STYLE_GRADIENT);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "direction"))
+			style->fill.gradient.dir = go_gradient_dir_from_str (attrs[1]);
+		else if (0 == strcmp (attrs[0], "start-color"))
+			go_color_from_str (attrs[1], &style->fill.pattern.back);
+		else if (0 == strcmp (attrs[0], "end-color"))
+			go_color_from_str (attrs[1], &style->fill.pattern.fore);
+		else if (0 == strcmp (attrs[0], "brightness"))
+			gog_style_set_fill_brightness (style, g_strtod (attrs[1], NULL));
+}
+
+static void
+gog_style_sax_load_fill (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "type"))
+			style->fill.type = str_as_fill_style (attrs[1]);
+		else if (bool_sax_prop ("is-auto", attrs[0], attrs[1], &style->fill.auto_back))
+			;
+		else if (bool_sax_prop ("auto-fore", attrs[0], attrs[1], &style->fill.auto_fore))
+			;
+}
+static void
+gog_style_sax_load_marker (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	GOMarker *marker = go_marker_dup (style->marker.mark);
+	GOColor c;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (bool_sax_prop ("auto-shape", attrs[0], attrs[1], &style->marker.auto_shape))
+			;
+		else if (0 == strcmp (attrs[0], "shape"))
+			go_marker_set_shape (marker, go_marker_shape_from_str (attrs[1]));
+		else if (bool_sax_prop ("auto-outline", attrs[0], attrs[1], &style->marker.auto_outline_color))
+			;
+		else if (0 == strcmp (attrs[0], "outline-color")) {
+			if (go_color_from_str (attrs[1], &c))
+				go_marker_set_outline_color (marker, c);
+		} else if (bool_sax_prop ("auto-fill", attrs[0], attrs[1], &style->marker.auto_fill_color))
+			;
+		else if (0 == strcmp (attrs[0], "fill-color")) {
+			if (go_color_from_str (attrs[1], &c))
+				go_marker_set_fill_color (marker, c);
+		} else if (0 == strcmp (attrs[0], "size"))
+			go_marker_set_size (marker, g_strtod (attrs[1], NULL));
+
+	gog_style_set_marker (style, marker);
+}
+
+static void
+gog_style_sax_load_font (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "color"))
+			go_color_from_str (attrs[1], &style->font.color);
+		else if (0 == strcmp (attrs[0], "font")) {
+			PangoFontDescription *desc = pango_font_description_from_string (attrs[1]);
+			if (desc != NULL)
+				gog_style_set_font_desc (style, desc);
+		} else if (bool_sax_prop ("auto-scale", attrs[0], attrs[1], &style->font.auto_scale))
+			;
+}
+static void
+gog_style_sax_load_text_layout (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	GogStyle *style = GOG_STYLE (xin->user_state);
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (0 == strcmp (attrs[0], "angle"))
+			gog_style_set_text_angle (style, g_strtod (attrs[1], NULL));
 }
 
 static void
@@ -1667,19 +1905,37 @@ gog_style_persist_sax_save (GogPersist const *gp, GsfXMLOut *output)
 		gog_style_marker_sax_save (output, style);
 	if (style->interesting_fields & GOG_STYLE_FONT)
 		gog_style_font_sax_save (output, style);
+	if (style->interesting_fields & GOG_STYLE_TEXT_LAYOUT)
+		gog_style_text_layout_sax_save (output, style);
 }
 
 static void
 gog_style_persist_init (GogPersistClass *iface)
 {
+	static GsfXMLInNode const gog_style_dtd[] = {
+	  GSF_XML_IN_NODE (STYLE, STYLE, -1, "GogObject", FALSE, NULL, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_LINE,		-1, "outline", FALSE, &gog_style_sax_load_line, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_OUTLINE,	-1, "line", FALSE, &gog_style_sax_load_line, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_FILL,		-1, "fill", FALSE, &gog_style_sax_load_fill, NULL),
+	      GSF_XML_IN_NODE (STYLE_FILL, FILL_PATTERN,  -1, "pattern",
+			       FALSE, &gog_style_sax_load_fill_pattern, NULL),
+	      GSF_XML_IN_NODE (STYLE_FILL, FILL_GRADIENT, -1, "gradient",
+			       FALSE, &gog_style_sax_load_fill_gradient, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_MARKER,	-1, "marker", FALSE, &gog_style_sax_load_marker, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_FONT,		-1, "font", FALSE, &gog_style_sax_load_font, NULL),
+	    GSF_XML_IN_NODE (STYLE, STYLE_ALIGNMENT,	-1, "text_layout", FALSE, &gog_style_sax_load_text_layout, NULL),
+	  GSF_XML_IN_NODE_END
+	};
 	iface->dom_load = gog_style_persist_dom_load;
 	iface->dom_save = gog_style_persist_dom_save;
 	iface->sax_save = gog_style_persist_sax_save;
+#warning PLUG LEAK
+	iface->sax_doc  = gsf_xml_in_doc_new (gog_style_dtd, NULL);
 }
 
 GSF_CLASS_FULL (GogStyle, gog_style,
-		gog_style_class_init, gog_style_init,
-		G_TYPE_OBJECT, 0,
+		NULL, NULL, gog_style_class_init, NULL,
+		gog_style_init, G_TYPE_OBJECT, 0,
 		GSF_INTERFACE (gog_style_persist_init, GOG_PERSIST_TYPE))
 
 gboolean
@@ -1691,6 +1947,7 @@ gog_style_is_different_size (GogStyle const *a, GogStyle const *b)
 		a->outline.width != b->outline.width ||
 		a->line.width != b->line.width ||
 		a->fill.type != b->fill.type ||
+		a->text_layout.angle != b->text_layout.angle ||
 		!go_font_eq (a->font.font, b->font.font);
 }
 
@@ -1734,7 +1991,8 @@ gog_style_force_auto (GogStyle *style)
 	style->line.auto_color =
 	style->fill.auto_fore =
 	style->fill.auto_back =
-	style->font.auto_scale = TRUE;
+	style->font.auto_scale =
+	style->text_layout.auto_angle = TRUE;
 }
 
 /**
@@ -1818,3 +2076,20 @@ gog_style_set_fill_image_filename (GogStyle *style, char *filename)
 	style->fill.image.filename = filename;
 	style->fill.image.image = gdk_pixbuf_new_from_file (filename, NULL);
 }
+
+/**
+ * gog_style_set_text_angle:
+ * @style : #GogStyle
+ * @angle : text rotation in degrees
+ *
+ * Set text rotation angle in degrees. Valid values are in the range
+ * [-180.0° , 180.0°].
+ **/
+void
+gog_style_set_text_angle (GogStyle *style, double angle)
+{
+	g_return_if_fail (GOG_STYLE (style) != NULL);
+
+	style->text_layout.angle = CLAMP (angle, -180.0, 180.0);
+	style->text_layout.auto_angle = FALSE;
+}
