@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <goffice/goffice-config.h>
@@ -40,7 +40,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <atk/atkrelation.h>
 #include <atk/atkrelationset.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-input-textline.h>
 
@@ -111,51 +111,48 @@ go_access (const char *filename, int what)
  * stock_id : id for stock icon
  *
  * return : newly created button
- *
  **/
 GtkWidget*
 go_gtk_button_new_with_stock (char const *text, char const* stock_id)
 {
-	GtkWidget *button;
 	GtkStockItem item;
-	GtkWidget *label;
-	GtkWidget *image;
-	GtkWidget *hbox;
-	GtkWidget *align;
+	GtkWidget *button = gtk_button_new_with_mnemonic (text);
+	if (gtk_stock_lookup (stock_id, &item))
+		gtk_button_set_image (GTK_BUTTON (button),
+			gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON));
+	return button;
+}
 
-	button = gtk_button_new ();
+/**
+ * go_gtk_dialog_add_button
+ * dialog : dialog you want to add a button
+ * text : button label
+ * stock_id : stock icon id
+ * response_id : respond id when button clicked
+ *
+ * Creates and adds a button with stock image to the action area of an existing dialog.
+ * Code from gedit
+ * 
+ * return : newly created button
+ **/
+GtkWidget*
+go_gtk_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
+			  gint response_id)
+{
+	GtkWidget *button;
 
-	if (GTK_BIN (button)->child)
-		gtk_container_remove (GTK_CONTAINER (button),
-				      GTK_BIN (button)->child);
+	g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
+	g_return_val_if_fail (text != NULL, NULL);
+	g_return_val_if_fail (stock_id != NULL, NULL);
 
-	if (gtk_stock_lookup (stock_id, &item)) {
-		label = gtk_label_new_with_mnemonic (text);
+	button = go_gtk_button_new_with_stock (text, stock_id);
+	g_return_val_if_fail (button != NULL, NULL);
 
-		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 
-		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-		hbox = gtk_hbox_new (FALSE, 2);
+	gtk_widget_show (button);
 
-		align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-
-		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-		gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-		gtk_container_add (GTK_CONTAINER (button), align);
-		gtk_container_add (GTK_CONTAINER (align), hbox);
-		gtk_widget_show_all (align);
-
-		return button;
-	}
-
-	label = gtk_label_new_with_mnemonic (text);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-
-	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-
-	gtk_widget_show (label);
-	gtk_container_add (GTK_CONTAINER (button), label);
+	gtk_dialog_add_action_widget (dialog, button, response_id);	
 
 	return button;
 }
@@ -578,9 +575,10 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *formats,
 		if (*ret_format)
 			sel_format = *ret_format;
 		for (l = formats, i = 0; l != NULL; l = l->next, i++) {
+#warning we must find a better solution for translating strings not in goffice domain
 			gtk_combo_box_append_text
 				(format_combo,
-				 ((GOImageType *) (l->data))->desc);
+				 gettext (((GOImageType *) (l->data))->desc));
 			if (l->data == (void *)sel_format)
 				gtk_combo_box_set_active (format_combo, i);
 		}
