@@ -37,7 +37,7 @@
 #include <goffice/utils/go-line.h>
 #include <goffice/app/module-plugin-defs.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtklabel.h>
 #include <gsf/gsf-impl-utils.h>
 #include <math.h>
